@@ -13,7 +13,13 @@ option add *font 			fixed 	startup
 option add *Text.c_link			blue	startup
 
 proc install_init { appName dotFile } {
-    global install
+    global install tk_version tk_patchLevel tcl_version tcl_patchLevel
+    # Work around namespaces issue in Tk8.4a2 and later
+    if [info exists tk_version] {
+        if {$tk_version > "8.3"} {
+            ::tk::unsupported::ExposePrivateCommand tkEntryBackspace
+        }
+    }
     set install(appName) $appName
     install_progVar wish [installGuessPath /usr/local/bin/wish wish] {wish absolute pathname}
     set install(dotFile) $dotFile
@@ -357,6 +363,9 @@ proc installVerify {} {
 	installFeedback "Verify OK"
 	return
     }
+    if {[winfo exists .verify]} {
+      destroy .verify
+    }
     toplevel .verify
     frame .verify.top
     button .verify.top.quit -text "Dismiss" -command {destroy .verify}
@@ -453,6 +462,9 @@ proc installPatch {} {
 	installFeedback "No diffs after patching"
 	return
     }
+    if {[winfo exists .test]} {
+      destroy .test
+    }
     toplevel .test
     frame .test.top
     button .test.top.quit -text "Dismiss" -command {destroy .test}
@@ -641,6 +653,9 @@ proc MakeDir { logProc dir } {
 }
 proc installFake {} {
     global exmh install
+    if {[winfo exists .fake]} {
+      destroy .fake
+    }
     toplevel .fake
     wm title .fake "Install Actions"
     wm iconname .fake "Install Actions"
