@@ -172,7 +172,7 @@ proc SeditInsertFile { draft t file {newpart 0} {encoding {}} {type text/plain}
 	    set inheaders 1
 	    set quoted 0
 	    while {[gets $in line] > -1} {
-		if {! $inheaders} {
+		if {! $inheaders || !$quote(symlink)} {
 		    $t insert insert $sedit(pref,replPrefix)$line\n
 		} else {
 		    # This simple hack doesn't work for multiparts.
@@ -183,6 +183,9 @@ proc SeditInsertFile { draft t file {newpart 0} {encoding {}} {type text/plain}
 			    set sedit($t,quote) 1
 			}
 		    }
+		    if {$quote(headers)} {
+			$t insert insert $sedit(pref,replPrefix)$line\n
+		    }
 		    if {[string length $line] == 0} {
 			set inheaders 0
 			if {$quoted} {
@@ -264,8 +267,8 @@ proc SeditCiteSelection { draft t } {
     regsub -all "\n\n+" $line \x01 line
 
     set space ""
-    set limit 70
-    set cutoff 50
+    set limit [expr {$sedit(lineLength) - [string length $sedit(pref,replPrefix)]}]
+    set cutoff [expr {int($limit * .8)}]
 
     regsub -all {]|[.^$*+|()\[\\]} $sedit(pref,replPrefix) {\\&} pattern
     foreach line [split $line \x01] {
